# __init__.py
from .thres import thres
from .cond import cond
from .equa import equa






